@@ -1,12 +1,12 @@
-/* $Id: paprefs.cc 30 2007-10-29 21:18:29Z lennart $ */
-
 /***
   This file is part of paprefs.
 
-  paprefs is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published
-  by the Free Software Foundation; either version 2 of the License,
-  or (at your option) any later version.
+  Copyright 2006-2008 Lennart Poettering
+
+  paprefs is free software; you can redistribute it and/or modify it
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 2 of the License, or
+  (at your option) any later version.
 
   paprefs is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,9 +14,7 @@
   General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with paprefs; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-  USA.
+  along with paprefs. If not, see <http://www.gnu.org/licenses/>.
 ***/
 
 #ifdef HAVE_CONFIG_H
@@ -28,6 +26,7 @@
 #include <gtkmm.h>
 #include <libglademm.h>
 #include <gconfmm.h>
+#include <libintl.h>
 
 #define PA_GCONF_ROOT "/system/pulseaudio"
 #define PA_GCONF_PATH_MODULES PA_GCONF_ROOT"/modules"
